@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# Copyright (C) 2000-2009 Peter Selinger.
+# Copyright (C) 2000-2012 Peter Selinger.
 # This file is part of ccrypt. It is free software and it is covered
 # by the GNU general public license. See the file COPYING for details.
 
@@ -18,7 +18,7 @@ NAME="$0"
 KEY=testkey
 KEY2=newkey
 KEYM=mismatchkey
-CCRYPT="../src/ccrypt -f"
+CCRYPT="${CHECK_CCRYPT:-../src/ccrypt$EXEEXT} -f"
 DATA="$srcdir"/testdata
 DATAM="$srcdir"/testdata.m
 CPTDATA="$srcdir"/testdata.cpt
@@ -45,6 +45,7 @@ naction () {
     if test "$RECEIVED" -ne "$EXPECTED"; then
 	echo "$NAME:$LINE: Action returned $RECEIVED instead of $EXPECTED." >&2
 	echo "$NAME: test failed." >&2
+	echo "Failed command: $LINE: $@" >& 2
 	exit 1
     fi
 }
