@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# Copyright (C) 2000-2009 Peter Selinger.
+# Copyright (C) 2000-2012 Peter Selinger.
 # This file is part of ccrypt. It is free software and it is covered
 # by the GNU general public license. See the file COPYING for details.
 
@@ -17,7 +17,7 @@ fi
 . "$srcdir"/common.sh
 
 NAME="$0"
-CCRYPT="../src/ccrypt -f -K testkey"
+CCRYPT="${CHECK_CCRYPT:-../src/ccrypt$EXEEXT} -f"
 
 if test "$1"; then
     TMPDIR="$1"
@@ -50,7 +50,7 @@ echo "Creating large file (>4GB)..."
 action dd if=/dev/zero of="$DATA" bs=1024 count=4200000 >/dev/null
 
 echo "Encrypting file..."
-action $CCRYPT "$DATA"
+action $CCRYPT -K testkey "$DATA"
 
 echo "$NAME: test succeeded" >&2
 cleanup
