@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# Copyright (C) 2000-2009 Peter Selinger.
+# Copyright (C) 2000-2012 Peter Selinger.
 # This file is part of ccrypt. It is free software and it is covered
 # by the GNU general public license. See the file COPYING for details.
 
@@ -17,7 +17,7 @@ NAME="$0"
 
 KEY=testkey
 KEY2=newkey
-CCRYPT="../src/ccrypt -f"
+CCRYPT="${CHECK_CCRYPT:-../src/ccrypt$EXEEXT} -f"
 DATA=`mktemp "$TMPDIR/ccrypt-length-check-1.XXXXXX"`
 TMP1=`mktemp "$TMPDIR/ccrypt-length-check-2.XXXXXX"`
 TMP2=`mktemp "$TMPDIR/ccrypt-length-check-3.XXXXXX"`
