@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2009 Peter Selinger.
+/* Copyright (C) 2000-2012 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
@@ -7,7 +7,6 @@
 #include <time.h>
 
 #include "rijndael-alg-ref.h"
-#define __RIJNDAEL_WORD
 #include "../src/rijndael.h"
 
 /* check to see if the optimized Rijndael implementation agrees with
@@ -22,8 +21,8 @@ int main() {
   word8 a[4][MAXBC];
   word8 a0[4][MAXBC];
   roundkey rkk;
-  word32 k1_32[MAXKC];
-  word32 a1_32[MAXBC];
+  xword32 k1_32[MAXKC];
+  xword32 a1_32[MAXBC];
   char* k1 = (char *)k1_32;
   char* a1 = (char *)a1_32;
 
