@@ -1,13 +1,13 @@
-/* Copyright (C) 2000-2009 Peter Selinger.
+/* Copyright (C) 2000-2012 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
 /* readkey.h */
-/* $Id: readkey.h 258 2009-08-26 17:46:10Z selinger $ */
+/* $Id: readkey.h 314 2012-10-15 16:35:56Z selinger $ */
 
 #ifndef __READKEY_H
 #define __READKEY_H
 
-char *readkey(const char *prompt, const char *promptcont, const char *myname);
+char *readkey(const char *prompt, const char *promptcont, const char *myname, int echo);
 
 #endif /* __READKEY_H */
