@@ -1,9 +1,9 @@
-/* Copyright (C) 2000-2009 Peter Selinger.
+/* Copyright (C) 2000-2012 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
 /* rijndael.c - optimized version of the Rijndeal cipher */
-/* $Id: rijndael.c 258 2009-08-26 17:46:10Z selinger $ */
+/* $Id: rijndael.c 305 2012-10-11 12:41:22Z selinger $ */
 
 /* derived from original source: rijndael-alg-ref.c   v2.0   August '99
  * Reference ANSI C code for NIST competition
@@ -26,8 +26,8 @@ static int xshifts[3][2][4] = {
 
 /* Exor corresponding text input and round key input bytes */
 /* the result is written to res, which can be the same as a */
-static inline void xKeyAddition(word32 res[MAXBC], word32 a[MAXBC],
-			 word32 rk[MAXBC], int BC)
+static inline void xKeyAddition(xword32 res[MAXBC], xword32 a[MAXBC],
+			 xword32 rk[MAXBC], int BC)
 {
   int j;
 
@@ -40,11 +40,11 @@ static inline void xKeyAddition(word32 res[MAXBC], word32 a[MAXBC],
 
 /* shift rows a, return result in res. This avoids having to copy a
    tmp array back to a. res must not be a. */
-static inline void xShiftRow(word32 res[MAXBC], word32 a[MAXBC], int shift[4],
+static inline void xShiftRow(xword32 res[MAXBC], xword32 a[MAXBC], int shift[4],
 		      int BC)
 {
-  word8 (*a8)[4] = (word8 (*)[4]) a;
-  word8 (*res8)[4] = (word8 (*)[4]) res;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
+  xword8 (*res8)[4] = (xword8 (*)[4]) res;
 
   /* Row 0 remains unchanged
    * The other three rows are shifted a variable amount
@@ -63,9 +63,9 @@ static inline void xShiftRow(word32 res[MAXBC], word32 a[MAXBC], int shift[4],
   }
 }
 
-static inline void xSubstitution(word32 a[MAXBC], word8 box[256], int BC)
+static inline void xSubstitution(xword32 a[MAXBC], xword8 box[256], int BC)
 {
-  word8 (*a8)[4] = (word8 (*)[4]) a;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
 
   /* Replace every byte of the input by the byte at that place
    * in the nonlinear S-box
@@ -90,13 +90,13 @@ static inline void xSubstitution(word32 a[MAXBC], word8 box[256], int BC)
    faster on most platforms. */
 
 /* do ShiftRow and Substitution together. res must not be a. */
-static inline void xShiftSubst(word32 res[MAXBC], word32 a[MAXBC],
-			int shift[4], int BC, word8 box[256])
+static inline void xShiftSubst(xword32 res[MAXBC], xword32 a[MAXBC],
+			int shift[4], int BC, xword8 box[256])
 {
   int i, j;
   int s;
-  word8 (*a8)[4] = (word8 (*)[4]) a;
-  word8 (*res8)[4] = (word8 (*)[4]) res;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
+  xword8 (*res8)[4] = (xword8 (*)[4]) res;
 
   for (j = 0; j < BC; j++) {
     res8[j][0] = box[a8[j][0]];
@@ -116,11 +116,11 @@ static inline void xShiftSubst(word32 res[MAXBC], word32 a[MAXBC],
 
 /* Mix the four bytes of every column in a linear way */
 /* the result is written to res, which may equal a */
-static inline void xMixColumn(word32 res[MAXBC], word32 a[MAXBC], int BC)
+static inline void xMixColumn(xword32 res[MAXBC], xword32 a[MAXBC], int BC)
 {
   int j;
-  word32 b;
-  word8 (*a8)[4] = (word8 (*)[4]) a;
+  xword32 b;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
 
   for (j = 0; j < BC; j++) {
     b = M0[0][a8[j][0]].w32;
@@ -134,12 +134,12 @@ static inline void xMixColumn(word32 res[MAXBC], word32 a[MAXBC], int BC)
 #endif				/* code included for reference */
 
 /* do MixColumn and KeyAddition together */
-static inline void xMixAdd(word32 res[MAXBC], word32 a[MAXBC],
-		    word32 rk[MAXBC], int BC)
+static inline void xMixAdd(xword32 res[MAXBC], xword32 a[MAXBC],
+		    xword32 rk[MAXBC], int BC)
 {
   int j;
-  word32 b;
-  word8 (*a8)[4] = (word8 (*)[4]) a;
+  xword32 b;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
 
   for (j = 0; j < BC; j++) {
     b = M0[0][a8[j][0]].w32;
@@ -154,11 +154,11 @@ static inline void xMixAdd(word32 res[MAXBC], word32 a[MAXBC],
 /* Mix the four bytes of every column in a linear way
  * This is the opposite operation of xMixColumn */
 /* the result is written to res, which may equal a */
-static inline void xInvMixColumn(word32 res[MAXBC], word32 a[MAXBC], int BC)
+static inline void xInvMixColumn(xword32 res[MAXBC], xword32 a[MAXBC], int BC)
 {
   int j;
-  word32 b;
-  word8 (*a8)[4] = (word8 (*)[4]) a;
+  xword32 b;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
 
   for (j = 0; j < BC; j++) {
     b = M1[0][a8[j][0]].w32;
@@ -172,12 +172,12 @@ static inline void xInvMixColumn(word32 res[MAXBC], word32 a[MAXBC], int BC)
 #if 0				/* code included for reference */
 
 /* do KeyAddition and InvMixColumn together */
-static inline void xAddInvMix(word32 res[MAXBC], word32 a[MAXBC],
-		       word32 rk[MAXBC], int BC)
+static inline void xAddInvMix(xword32 res[MAXBC], xword32 a[MAXBC],
+		       xword32 rk[MAXBC], int BC)
 {
   int j;
-  word32 b;
-  word8 (*a8)[4] = (word8 (*)[4]) a;
+  xword32 b;
+  xword8 (*a8)[4] = (xword8 (*)[4]) a;
 
   for (j = 0; j < BC; j++) {
     a[j] = a[j] ^ rk[j];
@@ -191,14 +191,14 @@ static inline void xAddInvMix(word32 res[MAXBC], word32 a[MAXBC],
 
 #endif				/* code included for reference */
 
-int xrijndaelKeySched(word32 key[], int keyBits, int blockBits,
+int xrijndaelKeySched(xword32 key[], int keyBits, int blockBits,
 		      roundkey *rkk)
 {
   /* Calculate the necessary round keys
    * The number of calculations depends on keyBits and blockBits */
   int KC, BC, ROUNDS;
   int i, j, t, rconpointer = 0;
-  word8 (*k8)[4] = (word8 (*)[4]) key;
+  xword8 (*k8)[4] = (xword8 (*)[4]) key;
 
   switch (keyBits) {
   case 128:
@@ -278,15 +278,15 @@ int xrijndaelKeySched(word32 key[], int keyBits, int blockBits,
 
 /* Encryption of one block. */
 
-void xrijndaelEncrypt(word32 block[], roundkey *rkk)
+void xrijndaelEncrypt(xword32 block[], roundkey *rkk)
 {
-  word32 block2[MAXBC];		/* hold intermediate result */
+  xword32 block2[MAXBC];		/* hold intermediate result */
   int r;
 
   int *shift = rkk->shift[0];
   int BC = rkk->BC;
   int ROUNDS = rkk->ROUNDS;
-  word32 *rp = rkk->rk;
+  xword32 *rp = rkk->rk;
 
   /* begin with a key addition */
   xKeyAddition(block, block, rp, BC);
@@ -304,15 +304,15 @@ void xrijndaelEncrypt(word32 block[], roundkey *rkk)
   xKeyAddition(block, block2, rp, BC);
 }
 
-void xrijndaelDecrypt(word32 block[], roundkey *rkk)
+void xrijndaelDecrypt(xword32 block[], roundkey *rkk)
 {
-  word32 block2[MAXBC];		/* hold intermediate result */
+  xword32 block2[MAXBC];		/* hold intermediate result */
   int r;
 
   int *shift = rkk->shift[1];
   int BC = rkk->BC;
   int ROUNDS = rkk->ROUNDS;
-  word32 *rp = rkk->rk + ROUNDS * BC;
+  xword32 *rp = rkk->rk + ROUNDS * BC;
 
   /* To decrypt: apply the inverse operations of the encrypt routine,
    *             in opposite order
