@@ -1,8 +1,8 @@
-/* Copyright (C) 2000-2009 Peter Selinger.
+/* Copyright (C) 2000-2012 Peter Selinger.
    This file is part of ccrypt. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
-/* $Id: unixcrypt3.c 258 2009-08-26 17:46:10Z selinger $ */
+/* $Id: unixcrypt3.c 305 2012-10-11 12:41:22Z selinger $ */
 /* A drop-in replacement for crypt(3), where it is not available as a
    library function. Derived from GNU sources and specialized. */
 
@@ -258,9 +258,7 @@ static ufc_long efp[16][64][2];
 #define SBA(sb, v) (*(long32*)((char*)(sb)+(v)))
 
 static void 
-_ufc_doit_r(itr, __data, res)
-     ufc_long itr, *res;
-     struct crypt_data *__data;
+_ufc_doit_r(ufc_long itr, struct crypt_data *__data, ufc_long *res)
 {
   int i;
   long32 s, *k;
@@ -299,8 +297,7 @@ _ufc_doit_r(itr, __data, res)
  */
 
 static void
-__init_des_r(__data)
-     struct crypt_data *__data;
+__init_des_r(struct crypt_data *__data)
 {
   int comes_from_bit;
   int bit, sg;
@@ -470,9 +467,7 @@ __init_des_r(__data)
  */
 
 static void
-shuffle_sb(k, saltbits)
-     long32 *k;
-     ufc_long saltbits;
+shuffle_sb(long32 *k, ufc_long saltbits)
 {
   ufc_long j;
   long32 x;
@@ -489,9 +484,7 @@ shuffle_sb(k, saltbits)
  */
 
 static void
-_ufc_setup_salt_r(s, __data)
-     const char *s;
-     struct crypt_data *__data;
+_ufc_setup_salt_r(const char *s, struct crypt_data *__data)
 {
   ufc_long i, j, saltbits;
 
@@ -531,9 +524,7 @@ _ufc_setup_salt_r(s, __data)
 }
 
 static void
-_ufc_mk_keytab_r(key, __data)
-     const char *key;
-     struct crypt_data *__data;
+_ufc_mk_keytab_r(const char *key, struct crypt_data *__data)
 {
   ufc_long v1, v2, *k1;
   int i;
@@ -575,9 +566,7 @@ _ufc_mk_keytab_r(key, __data)
  */
 
 static void
-_ufc_dofinalperm_r(res, __data)
-     ufc_long *res;
-     struct crypt_data *__data;
+_ufc_dofinalperm_r(ufc_long *res, struct crypt_data *__data)
 {
   ufc_long v1, v2, x;
   ufc_long l1,l2,r1,r2;
@@ -619,10 +608,7 @@ _ufc_dofinalperm_r(res, __data)
  */
 
 static void
-_ufc_output_conversion_r(v1, v2, salt, __data)
-     ufc_long v1, v2;
-     const char *salt;
-     struct crypt_data *__data;
+_ufc_output_conversion_r(ufc_long v1, ufc_long v2, const char *salt, struct crypt_data *__data)
 {
   int i, s, shf;
 
